@@ -3,10 +3,12 @@ from datetime import datetime
 from django.core import management
 from celery import Celery
 import os
+from django.conf import settings
 
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
 app = Celery('webspace.bakery')
 app.config_from_object('webspace.bakery.celeryconfig', namespace='CELERY')
+app.conf.task_default_queue = settings.SITE_NAME
 app.control.purge()
 app.autodiscover_tasks()
 
